==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-api/src/main/java/org/apache/nifi/web/search/attributematchers/ExecutionMatcher.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.web.search.attributematchers;

import org.apache.commons.lang3.StringUtils;
import org.apache.nifi.controller.ProcessorNode;
import org.apache.nifi.scheduling.ExecutionNode;
import org.apache.nifi.web.search.query.SearchQuery;

import java.util.List;

public class ExecutionMatcher implements AttributeMatcher<ProcessorNode>  {
    private static final String SEARCH_TERM = "primary";
    private static final String MATCH_LABEL = "Execution node: primary";

    @Override
    public void match(final ProcessorNode component, final SearchQuery query, final List<String> matches) {
        if (ExecutionNode.PRIMARY.equals(component.getExecutionNode()) && StringUtils.containsIgnoreCase(SEARCH_TERM, query.getTerm())) {
            matches.add(MATCH_LABEL);
        }
    }
}

==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-api/src/main/java/org/apache/nifi/web/search/attributematchers/ExecutionMatcher.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.web.search.attributematchers;

import org.apache.commons.lang3.Strings;
import org.apache.nifi.controller.ProcessorNode;
import org.apache.nifi.scheduling.ExecutionNode;
import org.apache.nifi.web.search.query.SearchQuery;

import java.util.List;

public class ExecutionMatcher implements AttributeMatcher<ProcessorNode>  {
    private static final String SEARCH_TERM = "primary";
    private static final String MATCH_LABEL = "Execution node: primary";

    @Override
    public void match(final ProcessorNode component, final SearchQuery query, final List<String> matches) {
        if (ExecutionNode.PRIMARY.equals(component.getExecutionNode()) && Strings.CI.contains(SEARCH_TERM, query.getTerm())) {
            matches.add(MATCH_LABEL);
        }
    }
}
